Core enums for streamdown parsing state.
These enums represent the various states that the parser can be in while processing streaming markdown input.
Enums
- Block
Type - Represents the type of block-level element being processed.
- Code
- Represents the type of code block or code-related state.
- Emit
Flag - Flags for special emit behavior.
- List
Type - Represents the type of list being processed.
- Table
State - Represents the current section of a table being processed.